@@ -21,13 +21,43 @@
 #include <QtCore/QDir>
 #include <QtCore/QStringList>
 #include <QtCore/QTextCodec>
+#include <QLoggingCategory>
 
 #include <kcharsets.h>
-#include <kdebug.h>
-#include <kglobal.h>
+#include <kio/global.h>
 
 #include "diffsettings.h"
 
+namespace {
+/// TODO: This should be replaced to QDir::relativeFilePath
+QString constructRelativePath( const QString& from, const QString& to )
+{
+	QUrl fromURL( from );
+	QUrl toURL( to );
+	QUrl root;
+	int upLevels = 0;
+
+	// Find a common root.
+	root = fromURL;
+	while( root.isValid() && !root.isParentOf( toURL ) ) {
+		root = KIO::upUrl(root);
+		upLevels++;
+	}
+
+	if( !root.isValid() ) return to;
+
+	QString relative;
+	for( ; upLevels > 0; upLevels-- ) {
+		relative += "../";
+	}
+
+	relative += QString( to ).replace( 0, root.path().length(), "" );
+	return relative;
+}
+}
+
+Q_DECLARE_LOGGING_CATEGORY(LIBKOMPAREDIFF2)
+
 KompareProcess::KompareProcess( DiffSettings* diffSettings, Kompare::DiffMode diffMode, const QString & source, const QString & destination, const QString &dir, Kompare::Mode mode )
 	: KProcess(),
 	m_diffSettings( diffSettings ),
@@ -99,12 +129,12 @@ void KompareProcess::writeCommandLine()
 	// load the executable into the KProcess
 	if ( m_diffSettings->m_diffProgram.isEmpty() )
 	{
-		kDebug(8101) << "Using the first diff in the path..." << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Using the first diff in the path...";
 		*this << "diff";
 	}
 	else
 	{
-		kDebug(8101) << "Using a user specified diff, namely: " << m_diffSettings->m_diffProgram << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Using a user specified diff, namely: " << m_diffSettings->m_diffProgram;
 		*this << m_diffSettings->m_diffProgram;
 	}
 
@@ -229,12 +259,12 @@ void KompareProcess::setEncoding( const QString& encoding )
 	}
 	else
 	{
-		m_codec = KGlobal::charsets()->codecForName( encoding.toLatin1() );
+		m_codec = KCharsets::charsets()->codecForName( encoding.toLatin1() );
 		if ( m_codec )
 			m_textDecoder = m_codec->makeDecoder();
 		else
 		{
-			kDebug(8101) << "Using locale codec as backup..." << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Using locale codec as backup...";
 			m_codec = QTextCodec::codecForLocale();
 			m_textDecoder = m_codec->makeDecoder();
 		}
@@ -250,7 +280,7 @@ void KompareProcess::start()
 	QStringList::ConstIterator end = program.constEnd();
 	for (; it != end; ++it )
 		cmdLine += "\"" + (*it) + "\" ";
-	kDebug(8101) << cmdLine << endl;
+	qCDebug(LIBKOMPAREDIFF2) << cmdLine;
 #endif
 	setOutputChannelMode( SeparateChannels );
 	setNextOpenMode(QIODevice::ReadWrite);
@@ -271,12 +301,12 @@ void KompareProcess::slotFinished( int exitCode, QProcess::ExitStatus exitStatus
 		m_stderr = m_textDecoder->toUnicode( readAllStandardError() );
 	}
 	else
-		kDebug(8101) << "KompareProcess::slotFinished : No decoder !!!" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "KompareProcess::slotFinished : No decoder !!!";
 
 	// exit code of 0: no differences
 	//              1: some differences
 	//              2: error but there may be differences !
-	kDebug(8101) << "Exited with exit code : " << exitCode << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Exited with exit code : " << exitCode;
 	emit diffHasFinished( exitStatus == NormalExit && exitCode != 0 );
 }
 
